QuerySpec

Trait QuerySpec 

pub trait QuerySpec { }
Type level specification of a query for a certain set of components.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl QuerySpec for ()

Source

impl<A, B, C, D, E, F, G, H, I, J> QuerySpec for (A, B, C, D, E, F, G, H, I, J)

Source

impl<A, B, C, D, E, F, G, H, I> QuerySpec for (A, B, C, D, E, F, G, H, I)

Source

impl<A, B, C, D, E, F, G, H> QuerySpec for (A, B, C, D, E, F, G, H)

Source

impl<A, B, C, D, E, F, G> QuerySpec for (A, B, C, D, E, F, G)

Source

impl<A, B, C, D, E, F> QuerySpec for (A, B, C, D, E, F)

Source

impl<A, B, C, D, E> QuerySpec for (A, B, C, D, E)
where A: QuerySpec, B: QuerySpec, C: QuerySpec, D: QuerySpec, E: QuerySpec,

Source

impl<A, B, C, D> QuerySpec for (A, B, C, D)
where A: QuerySpec, B: QuerySpec, C: QuerySpec, D: QuerySpec,

Source

impl<A, B, C> QuerySpec for (A, B, C)
where A: QuerySpec, B: QuerySpec, C: QuerySpec,

Source

impl<A, B> QuerySpec for (A, B)
where A: QuerySpec, B: QuerySpec,

Source

impl<A> QuerySpec for (A,)
where A: QuerySpec,

Source

impl<C> QuerySpec for &C
where C: 'static,

Source

impl<C> QuerySpec for &mut C
where C: 'static,

Source

impl<S> QuerySpec for Option<S>
where S: QuerySpec,

Implementors

Source

impl<S, C> QuerySpec for With<S, C>
where S: QuerySpec, C: 'static,

Source

impl<S, C> QuerySpec for Without<S, C>
where S: QuerySpec, C: 'static,

Source

impl<S> QuerySpec for Matches<S>
where S: QuerySpec,