pub trait QuerySpec { }Expand description
Type level specification of a query for a certain set of components.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait QuerySpec { }Type level specification of a query for a certain set of components.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".